@@ -18,9 +18,9 @@
 ;;;
 ;;; Send bug reports to kyle@uunet.uu.net.
 
-(provide 'tapestry)
+;;(provide 'tapestry)
 
-(defvar tapestry-version "1.08")
+(defvar tapestry-version "1.09")
 
 ;; Pass state information between the tapestry-set-window-map
 ;; and tapestry-set-buffer-map stages.  UGH.  The reason for this
@@ -205,7 +205,11 @@ ROOT-WINDOW-EDGES will be used."
 	  root-window )
       (if (tapestry-windows-match-map map map-width map-height)
 	  (tapestry-first-window)
-	(delete-other-windows)
+	(if (fboundp 'frame-reduce-to-one-window)
+	    (frame-reduce-to-one-window (selected-frame))
+	  ;; `delete-other-windows' may cause the window point to move
+	  ;; as it tries to minimize redisplay
+	  (delete-other-windows))
 	(setq root-window (selected-window))
 	(tapestry-apply-window-map map map-width map-height root-window)
 	(setq tapestry-windows-changed t)
@@ -258,12 +262,12 @@ ROOT-WINDOW-EDGES will be used."
 	    current-wb (window-buffer (car w-list)))
       ;; Setting the window buffer to the same value it already
       ;; has seems to confuse XEmacs' scroll-up function.  But
-      ;; _not_ setting after windows torn down seem to cause
+      ;; _not_ setting it after windows torn down seem to cause
       ;; window point to sometimes drift away from point at
       ;; redisplay time.  The solution (hopefully!) is to track
       ;; when windows have been rearranged and unconditionally do
       ;; the set-window-buffer, otherwise do it only if the
-      ;; window buffer and the prosed window buffer differ.
+      ;; window buffer and the proposed window buffer differ.
       (if (or tapestry-windows-changed (not (eq proposed-wb current-wb)))
 	  (set-window-buffer (car w-list) proposed-wb))
       (setq w-list (cdr w-list)
@@ -539,7 +543,9 @@ ROOT-WINDOW-EDGES will be used."
     (and left top right bottom (list left top right bottom))))
 
 (defun tapestry-window-edges (&optional window)
-  (if (fboundp 'window-pixel-edges)
+  (if (and (fboundp 'window-pixel-edges)
+	   (fboundp 'face-width)
+	   (fboundp 'face-height))
       (let ((edges (window-pixel-edges window))
 	    tmp)
 	(setq tmp edges)
@@ -605,3 +611,5 @@ ROOT-WINDOW-EDGES will be used."
   (if (fboundp 'frame-live-p)
       (frame-live-p f)
     t ))
+
+(provide 'tapestry)
